package org.eclipse.equinox.launcher;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.IOException;
import java.net.JarURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.jar.Manifest;
import org.eclipse.equinox.launcher.Main;

public class WebStartMain extends Main {
  private static final String PROP_WEBSTART_AUTOMATIC_INSTALLATION = "eclipse.webstart.automaticInstallation";
  
  private static final String DEFAULT_OSGI_BUNDLES = "org.eclipse.equinox.common@2:start, org.eclipse.core.runtime@start";
  
  private static final String PROP_OSGI_BUNDLES = "osgi.bundles";
  
  private static final String PROP_CHECK_CONFIG = "osgi.checkConfiguration";
  
  private Map allBundles = null;
  
  private List bundleList = null;
  
  public static void main(String[] args) {
    System.setSecurityManager(null);
    int result = (new org.eclipse.equinox.launcher.WebStartMain()).run(args);
    if (!Boolean.getBoolean("osgi.noShutdown"))
      System.exit(result); 
  }
  
  private void setDefaultBundles() {
    if (System.getProperty("osgi.bundles") != null)
      return; 
    System.getProperties().put("osgi.bundles", "org.eclipse.equinox.common@2:start, org.eclipse.core.runtime@start");
  }
  
  protected void basicRun(String[] args) throws Exception {
    setDefaultBundles();
    initializeBundleListStructure();
    discoverBundles();
    String fwkURL = searchFor(this.framework, null);
    this.allBundles.remove(this.framework);
    System.getProperties().put("osgi.framework", fwkURL);
    super.basicRun(args);
  }
  
  protected void beforeFwkInvocation() {
    if (System.getProperty("osgi.checkConfiguration") == null)
      System.getProperties().put("osgi.checkConfiguration", "true"); 
    buildOSGiBundleList();
    cleanup();
  }
  
  private void cleanup() {
    this.allBundles = null;
    this.bundleList = null;
  }
  
  protected String searchFor(String target, String start) {
    ArrayList matches = (ArrayList)this.allBundles.get(target);
    if (matches == null)
      return null; 
    int numberOfMatches = matches.size();
    if (numberOfMatches == 1)
      return ((BundleInfo)matches.get(0)).location; 
    if (numberOfMatches == 0)
      return null; 
    String[] versions = new String[numberOfMatches];
    int highest = 0;
    for (int i = 0; i < versions.length; i++) {
      versions[i] = ((BundleInfo)matches.get(i)).version;
      highest = findMax(versions);
    } 
    return ((BundleInfo)matches.get(highest)).location;
  }
  
  private BundleInfo findBundle(String target, String version, boolean removeMatch) {
    ArrayList<BundleInfo> matches = (ArrayList)this.allBundles.get(target);
    int numberOfMatches = matches.size();
    if (numberOfMatches == 1)
      return matches.remove(0); 
    if (numberOfMatches == 0)
      return null; 
    if (version != null) {
      for (Iterator<BundleInfo> iterator = matches.iterator(); iterator.hasNext(); ) {
        BundleInfo bi = iterator.next();
        if (bi.version.equals(version)) {
          iterator.remove();
          return bi;
        } 
      } 
      return null;
    } 
    String[] versions = new String[numberOfMatches];
    int highest = 0;
    for (int i = 0; i < versions.length; i++) {
      versions[i] = ((BundleInfo)matches.get(i)).version;
      highest = findMax(versions);
    } 
    return matches.remove(highest);
  }
  
  private void discoverBundles() {
    this.allBundles = new HashMap<Object, Object>();
    try {
      Enumeration<URL> resources = org.eclipse.equinox.launcher.WebStartMain.class.getClassLoader().getResources("META-INF/MANIFEST.MF");
      while (resources.hasMoreElements()) {
        BundleInfo found = getBundleInfo(resources.nextElement());
        if (found == null)
          continue; 
        ArrayList<BundleInfo> matching = (ArrayList)this.allBundles.get(found.bsn);
        if (matching == null) {
          matching = new ArrayList(1);
          this.allBundles.put(found.bsn, matching);
        } 
        matching.add(found);
      } 
    } catch (IOException e) {
      e.printStackTrace();
    } 
  }
  
  private String extractInnerURL(URL url) {
    try {
      URLConnection connection = null;
      try {
        connection = url.openConnection();
        if (connection instanceof JarURLConnection)
          return "file:" + ((JarURLConnection)connection).getJarFile().getName(); 
      } finally {
        if (connection != null)
          connection.getInputStream().close(); 
      } 
    } catch (IOException iOException) {}
    return url.toExternalForm();
  }
  
  private void initializeBundleListStructure() {
    String prop = System.getProperty("osgi.bundles");
    if (prop == null || prop.trim().equals("")) {
      this.bundleList = new ArrayList(0);
      return;
    } 
    this.bundleList = new ArrayList(10);
    StringTokenizer tokens = new StringTokenizer(prop, ",");
    while (tokens.hasMoreTokens()) {
      String token = tokens.nextToken().trim();
      String bundleId = token;
      if (token.equals(""))
        continue; 
      BundleInfo toAdd = new BundleInfo(this, null);
      toAdd.bsn = bundleId;
      int startLevelSeparator;
      if ((startLevelSeparator = token.lastIndexOf('@')) != -1) {
        toAdd.bsn = token.substring(0, startLevelSeparator);
        toAdd.startData = token.substring(startLevelSeparator);
      } 
      this.bundleList.add(toAdd);
    } 
  }
  
  private BundleInfo getBundleInfo(URL manifestURL) {
    try {
      Manifest mf = new Manifest(manifestURL.openStream());
      String symbolicNameString = mf.getMainAttributes().getValue("Bundle-SymbolicName");
      if (symbolicNameString == null)
        return null; 
      BundleInfo result = new BundleInfo(this, null);
      String version = mf.getMainAttributes().getValue("Bundle-Version");
      result.version = (version != null) ? version : "0.0.0";
      result.location = extractInnerURL(manifestURL);
      int pos = symbolicNameString.lastIndexOf(';');
      if (pos != -1) {
        result.bsn = symbolicNameString.substring(0, pos);
        return result;
      } 
      result.bsn = symbolicNameString;
      return result;
    } catch (IOException e) {
      if (this.debug)
        e.printStackTrace(); 
      return null;
    } 
  }
  
  private void buildOSGiBundleList() {
    StringBuffer finalBundleList = new StringBuffer(this.allBundles.size() * 30);
    for (Iterator<BundleInfo> iterator = this.bundleList.iterator(); iterator.hasNext(); ) {
      BundleInfo searched = iterator.next();
      BundleInfo found = findBundle(searched.bsn, searched.version, true);
      finalBundleList.append("reference:").append(found.location).append(searched.startData).append(',');
    } 
    if (!Boolean.FALSE.toString().equalsIgnoreCase(System.getProperties().getProperty("eclipse.webstart.automaticInstallation")))
      for (Iterator<ArrayList> iterator1 = this.allBundles.values().iterator(); iterator1.hasNext(); ) {
        ArrayList toAdd = iterator1.next();
        for (Iterator<BundleInfo> iterator2 = toAdd.iterator(); iterator2.hasNext(); ) {
          BundleInfo bi = iterator2.next();
          finalBundleList.append("reference:").append(bi.location).append(',');
        } 
      }  
    System.getProperties().put("osgi.bundles", finalBundleList.toString());
  }
}
